@@ -1,4 +1,4 @@
-from .config import *
+from .__config__ import *
 import torch.nn as nn
 import torch.nn.functional as F
 
@@ -14,10 +14,10 @@ class ReLU(nn.Module):
     Examples::
         >>> import torch, torchact
         >>> m = torchact.ReLU()
-        >>> input = torch.tensor([1, -2, 0, 3])
+        >>> input = torch.tensor([1.0, -2.0, 0.0, 3.0])
         >>> output = m(input)
         >>> print(output)
-        tensor([1, 0, 0, 3])
+        tensor([1., 0., 0., 3.])
     """
 
     def __init__(self, inplace: bool = FALSE_CONDITION):
